﻿using Infragistics.Win.UltraWinDataSource;
using System;
using System.Collections.Generic;
using System.Drawing;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;

namespace UltraGridVirtualMode
{
    public partial class Form1 : Form
    {
        readonly IList<Data> myData;
        readonly Random random = new Random();

        public Form1()
        {
            myData = new List<Data>();
            InitializeComponent();
            ultraGrid1.Font = new Font("Segoe UI", 7.5f);
            PopulateData();
        }

        private void PopulateData()
        {
            for (int i = 1; i <= 20; i++)
                myData.Add(new Data {Id = i, Int = random.Next(), Double = random.NextDouble() * 1000 - 500 });
        }

        private void ultraGrid1_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            e.Layout.Override.MinRowHeight = 6;
            e.Layout.Override.DefaultRowHeight = 19;
            e.Layout.Appearance.TextVAlign = VAlign.Middle;
            e.Layout.LoadStyle = LoadStyle.LoadOnDemand;
            e.Layout.Override.RowSizing = RowSizing.Fixed;
            e.Layout.Override.HeaderAppearance.TextHAlign = HAlign.Left;
            e.Layout.Override.CellPadding = 0;
            e.Layout.Override.RowSelectorHeaderStyle = RowSelectorHeaderStyle.SeparateElement;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraGrid1.DataSource = this.ultraDataSource1;

            // Add three columns to the root band. 
            this.ultraDataSource1.Band.Columns.Add("ID", typeof(int));
            this.ultraDataSource1.Band.Columns.Add("Col0", typeof(double));
            this.ultraDataSource1.Band.Columns.Add("Col1", typeof(int));

            // Set the count on the root rows collection to 100. 
            this.ultraDataSource1.Rows.SetCount(myData.Count);

            this.ultraGrid1.DisplayLayout.Bands[0].Columns["Col0"].CellAppearance.TextHAlign = HAlign.Right;
            this.ultraGrid1.DisplayLayout.Bands[0].Columns["Col0"].Format = "#,##0.00;(#,##0.00)";
        }

        private void ultraDataSource1_CellDataRequested(object sender, CellDataRequestedEventArgs e)
        {
            int row = e.Row.Index;
            if (row >= 0 && row < myData.Count)
            {
                Data data = myData[row];
                switch (e.Column.Key)
                {
                    case "ID":
                        e.Data = data.Id;
                        break;
                    case "Col0":
                        e.Data = data.Double;
                        break;
                    case "Col1":
                        e.Data = data.Int;
                        break;
                }
                e.CacheData = false;
            }
        }

        struct Data
        {
            public int Id;
            public int Int;
            public double Double;
        }
    }
}